###
API
###

Core
====

.. automodapi:: jdaviz.core.events
   :no-inheritance-diagram:

.. automodapi:: jdaviz.core.helpers
   :no-inheritance-diagram:

.. automodapi:: jdaviz.core.registries
   :no-inheritance-diagram:

.. automodapi:: jdaviz.core.template_mixin
   :no-inheritance-diagram:

.. automodapi:: jdaviz.core.astrowidgets_api
   :no-inheritance-diagram:

Application
===========

.. automodapi:: jdaviz.app
   :no-inheritance-diagram:
   :no-inherited-members:


Configurations
==============

.. automodapi:: jdaviz.configs.default
   :no-inheritance-diagram:

.. automodapi:: jdaviz.configs.default.plugins.line_lists.line_list_mixin
   :no-inheritance-diagram:

.. automodapi:: jdaviz.configs.cubeviz
   :no-inheritance-diagram:

.. automodapi:: jdaviz.configs.imviz.helper
   :no-inheritance-diagram:

.. automodapi:: jdaviz.configs.imviz.plugins
   :no-inheritance-diagram:

.. automodapi:: jdaviz.configs.mosviz
   :no-inheritance-diagram:

.. automodapi:: jdaviz.configs.specviz
   :no-inheritance-diagram:

.. automodapi:: jdaviz.configs.specviz2d
   :no-inheritance-diagram:
